diff --git a/core/modules/block/lib/Drupal/block/Plugin/views/display/Block.php b/core/modules/block/lib/Drupal/block/Plugin/views/display/Block.php
index 04c5f04..81923e3 100644
--- a/core/modules/block/lib/Drupal/block/Plugin/views/display/Block.php
+++ b/core/modules/block/lib/Drupal/block/Plugin/views/display/Block.php
@@ -176,7 +176,7 @@ public function submitOptionsForm(&$form, &$form_state) {
    * Block views use exposed widgets only if AJAX is set.
    */
   public function usesExposed() {
-      if ($this->isAJAXEnabled()) {
+      if ($this->ajaxEnabled()) {
         return parent::usesExposed();
       }
       return FALSE;
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
index b0c6511..1af5b42 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
@@ -244,7 +244,7 @@ public function usesAJAX() {
    *
    * @return bool
    */
-  public function isAJAXEnabled() {
+  public function ajaxEnabled() {
     if ($this->usesAJAX()) {
       return $this->getOption('use_ajax');
     }
@@ -2488,7 +2488,7 @@ public function access($account = NULL) {
    * overridden on an individual display.
    */
   public function preExecute() {
-    $this->view->setUseAJAX($this->isAJAXEnabled());
+    $this->view->setAjaxEnabled($this->ajaxEnabled());
     if ($this->usesMore() && !$this->useMoreAlways()) {
       $this->view->get_total_rows = TRUE;
     }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php b/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
index a1d48f3..1fe792d 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
@@ -33,7 +33,7 @@ class Feed extends PathPluginBase {
    *
    * @var bool
    */
-  protected $usesAJAX = FALSE;
+  protected $ajaxEnabled = FALSE;
 
   /**
    * Whether the display allows the use of a pager or not.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
index b8d2e74..6be2dc8 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
@@ -250,7 +250,8 @@ public function testRenderNullPager() {
     }
     $view = views_get_view('test_pager_full');
     $this->executeView($view);
-    $view->use_ajax = TRUE; // force the value again here
+    // Force the value again here.
+    $view->setAjaxEnabled(TRUE);
     $view->pager = NULL;
     $output = $view->render();
     $output = drupal_render($output);
diff --git a/core/modules/views/views.theme.inc b/core/modules/views/views.theme.inc
index 395f275..35ca434 100644
--- a/core/modules/views/views.theme.inc
+++ b/core/modules/views/views.theme.inc
@@ -130,7 +130,7 @@ function template_preprocess_views_view(&$vars) {
   }
 
   // If using AJAX, send identifying data about this view.
-  if ($view->use_ajax && empty($view->is_attachment) && empty($view->live_preview)) {
+  if ($view->ajaxEnabled() && empty($view->is_attachment) && empty($view->live_preview)) {
     $settings = array(
       'views' => array(
         'ajax_path' => url('views/ajax'),

diff --git a/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php b/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
index b5c6711..864310e 100644
--- a/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
@@ -56,7 +56,6 @@ class ViewExecutableTest extends ViewUnitTestBase {
     'executed',
     'args',
     'build_info',
-    'use_ajax',
     'result',
     'attachment_before',
     'attachment_after',
@@ -190,10 +189,10 @@ public function testDisplays() {
   public function testPropertyMethods() {
     $view = views_get_view('test_executable_displays');
 
-    // Test the setUseAJAX() method.
-    $this->assertFalse($view->use_ajax);
-    $view->setUseAJAX(TRUE);
-    $this->assertTrue($view->use_ajax);
+    // Test the setAjaxEnabled() method.
+    $this->assertFalse($view->ajaxEnabled());
+    $view->setAjaxEnabled(TRUE);
+    $this->assertTrue($view->ajaxEnabled());
 
     $view->setDisplay();
     // There should be no pager set initially.
diff --git a/core/modules/views/lib/Drupal/views/ViewExecutable.php b/core/modules/views/lib/Drupal/views/ViewExecutable.php
index 7447488..da5648c 100644
--- a/core/modules/views/lib/Drupal/views/ViewExecutable.php
+++ b/core/modules/views/lib/Drupal/views/ViewExecutable.php
@@ -67,7 +67,7 @@ class ViewExecutable {
    *
    * @var bool
    */
-  public $use_ajax = FALSE;
+  protected $ajaxEnabled = FALSE;
 
   /**
    * Where the results of a query will go.
@@ -533,12 +533,27 @@ public function usePager() {
   }
 
   /**
-   * Whether or not AJAX should be used. If AJAX is used, paging,
-   * tablesorting and exposed filters will be fetched via an AJAX call
-   * rather than a page refresh.
+   * Sets whether or not AJAX should be used.
+   *
+   * If AJAX is used, paging, tablesorting and exposed filters will be fetched
+   * via an AJAX call rather than a page refresh.
+   *
+   * @param bool $use_ajax
+   *   TRUE if AJAX should be used, FALSE otherwise.
+   */
+  public function setAjaxEnabled($ajax_enabled) {
+    $this->ajaxEnabled = (bool) $ajax_enabled;
+  }
+
+  /**
+   * Whether or not AJAX should be used.
+   *
+   * @see \Drupal\views\ViewExecutable::setAjaxEnabled().
+   *
+   * @return bool
    */
-  public function setUseAJAX($use_ajax) {
-    $this->use_ajax = $use_ajax;
+  public function ajaxEnabled() {
+    return $this->ajaxEnabled;
   }
 
   /**